/***************************************************************************
 *   Copyright (C) 2005 by Sebastian Beck                                  *
 *   sebastian.bw@freenet.de                                                          *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include <kdialog.h>
#include <klocale.h>

#include "frage.h"

#include <qframe.h>
#include <qgroupbox.h>
#include <qlabel.h>
#include <qlayout.h>
#include <qpushbutton.h>
#include <qtextedit.h>
#include <qtooltip.h>
#include <qvariant.h>
#include <qwhatsthis.h>



Frage::Frage( QWidget* parent, const char* name, WFlags fl )	: QWidget( parent, name, fl )
	{
	if ( !name )
		setName( "Frage" );
	
	FrageLayout = new QGridLayout( this, 4, 6, 0, -1, "FrageLayout" );
	FrageLayout->setResizeMode( QLayout::Fixed );

	frage_group = new QGroupBox( this, "groupBox61" );
	frage_group->setMinimumSize( QSize( 240, 220 ) );
	frage_group->setMaximumSize( QSize( 240, 220 ) );
	frage_group->setColumnLayout( 0, Qt::Vertical );
	frage_group->layout()->setSpacing( 5 );
	frage_group->layout()->setMargin( 10 );
	frage_groupLayout = new QGridLayout( frage_group->layout(), 5, 3 );
	frage_groupLayout->setAlignment( Qt::AlignTop );
	FrageLayout->addWidget( frage_group, 0, 0 );

	tl1 = new QLabel( frage_group, "Frage" );
	tl1->setMinimumSize( QSize( 0, 14 ) );
	tl1->setMaximumSize( QSize( 32767, 14 ) );
	tl1->setPaletteForegroundColor( QColor( 0, 132, 188 ) );
	frage_groupLayout->addMultiCellWidget( tl1, 1, 1, 0, 1 );

	frage = new QTextEdit( frage_group, "frage" );
	frage->setMinimumSize( QSize( 0, 70 ) );
	frage->setMaximumSize( QSize( 32767, 70 ) );
	QFont frage_font( frage->font() );
	frage_font.setFamily( "Helvetica" );
	frage_font.setPointSize( 9 );
	frage->setFont( frage_font );
	frage->setVScrollBarMode( QTextEdit::AlwaysOff );
	frage->setHScrollBarMode( QTextEdit::Auto );
	frage->setWordWrap( QTextEdit::WidgetWidth );
	frage->setWrapPolicy( QTextEdit::Anywhere );
	frage_groupLayout->addMultiCellWidget( frage, 2, 2, 0, 3 );

	tl_num = new QLabel( frage_group, "Nummer" );
	tl_num->setMinimumSize( QSize( 0, 14 ) );
	tl_num->setMaximumSize( QSize( 32767, 14 ) );
	frage_groupLayout->addWidget( tl_num, 3, 0 );
	
	num = new HistoryIntInput( frage_group, "num" );
	num->setMinimumSize( QSize( 0, 20 ) );
	num->setMaximumSize( QSize( 50, 20 ) );
	num->setAcceptDrops( TRUE );
	num->setMaxValue( 999 );
	frage_groupLayout->addWidget( num, 3, 1 );

	einfuegen = new QPushButton( frage_group, "einfuegen" );
	einfuegen->setMinimumSize( QSize( 0, 27 ) );
	einfuegen->setMaximumSize( QSize( 32767, 27 ) );
	frage_groupLayout->addMultiCellWidget( einfuegen, 3, 3, 2, 3 );

	line1 = new QFrame( frage_group, "line1" );
	line1->setMinimumSize( QSize( 0, 5 ) );
	line1->setMaximumSize( QSize( 32767, 5 ) );
	line1->setFrameShape( QFrame::HLine );
	line1->setFrameShadow( QFrame::Sunken );
	line1->setFrameShape( QFrame::HLine );
	frage_groupLayout->addMultiCellWidget( line1, 4, 4, 0, 3 );

	tl_ziel = new QLabel( frage_group, "Sprungziel" );
	tl_ziel->setMinimumSize( QSize( 0, 14 ) );
	tl_ziel->setMaximumSize( QSize( 32767, 14 ) );
	tl_ziel->setPaletteForegroundColor( QColor( 0, 132, 188 ) );
	frage_groupLayout->addMultiCellWidget( tl_ziel, 5, 5, 0, 1 );

	frame1 = new QFrame( frage_group, "frame1" );
	frame1->setMinimumSize( QSize( 0, 25 ) );
	frame1->setMaximumSize( QSize( 32767, 25 ) );
	frame1->setPaletteBackgroundColor( QColor( 255, 255, 255 ) );
	frame1->setFrameShape( QFrame::TabWidgetPanel );
	frame1->setFrameShadow( QFrame::Sunken );
	frame1Layout = new QGridLayout( frame1, 1, 1, 3, 5, "frame1Layout" );
	frage_groupLayout->addWidget( frame1, 6, 0 );

	tl_frage = new QLabel( frame1, "> FRAGE" );
	tl_frage->setMinimumSize( QSize( 0, 20 ) );
	tl_frage->setMaximumSize( QSize( 32767, 20 ) );
	frame1Layout->addWidget( tl_frage, 0, 0 );

	num1 = new HistoryIntInput( frage_group, "num_ziel" );
	num1->setMinimumSize( QSize( 0, 20 ) );
	num1->setMaximumSize( QSize( 50, 20 ) );
	num1->setAcceptDrops( TRUE );
	num1->setMaxValue( 999 );
	frage_groupLayout->addWidget( num1, 6, 1 );

	einfuegen1 = new QPushButton( frage_group, "einfuegen_ziel" );
	einfuegen1->setMinimumSize( QSize( 0, 27 ) );
	einfuegen1->setMaximumSize( QSize( 32767, 27 ) );
	frage_groupLayout->addMultiCellWidget( einfuegen1, 6, 6, 2, 3 );
	
	languageChange();
	clearWState( WState_Polished );

	setTabOrder( frage, einfuegen );
//	frage->setFocus();
	}

Frage::~Frage()
	{
	}

void Frage::languageChange()
	{
	QToolTip::add( frage, tr2i18n( "<p>Soll gesprungen werden?<br>Antworten sie mit ja [J] oder nein mit belieger anderer Taste<p>" ) );
	setCaption( tr2i18n( "Frage" ) );
	frage_group->setTitle( tr2i18n( "Frage" ) );
	tl1->setText( tr2i18n( "Frage:" ) );
	tl_num->setText( tr2i18n( "Nummer:" ) );
	einfuegen->setText( tr2i18n( "&Einfügen" ) );
	tl_ziel->setText( tr2i18n( "Sprungziel :" ) );
	tl_frage->setText( tr2i18n( "> FRAGE" ) );
	einfuegen1->setText( tr2i18n( "E&infügen" ) );
	}


#include "frage.moc"
