/***************************************************************************
 *   Copyright (C) 2005 by Sebastian Beck                                  *
 *   sebastian.bw@freenet.de                                                    
     *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef HISTORYINTINPUT_H
#define HISTORYINTINPUT_H

#include <kcompletionbox.h>
#include <klocale.h>

#include <qvariant.h>
#include <qwidget.h>
#include <qpushbutton.h>
#include <qlineedit.h>
#include <qlayout.h>
#include <qtooltip.h>
#include <qwhatsthis.h>
#include <qpixmap.h>
#include <qimage.h> 
#include <qframe.h>
#include <qevent.h>
#include <qvalidator.h>

/**
	* @short This is a integer number input with history for KDE 3.x and later.
	*This input widget has a history popup by default.
	*For  integer validation is used a QIntValidator.
	*Global used image for popup button is "unsigned char img0_doubleinputwidget[]".
	*Value is recognized and set on return and on lostFocus event.
	@author Sebastian Beck <sebastian.bw@freenet.de>
*/
class HistoryIntInput : public QFrame
	{
	Q_OBJECT
	public:
	HistoryIntInput(QWidget *parent = 0, int v = 0, uint prec = 2, int min = -2147483647, int max = 2147483648, const char *name = 0);
	HistoryIntInput(QWidget *parent = 0, const char *name = 0);
	
	~HistoryIntInput();
	
	int Value, MinValue, MaxValue;
	
	QGridLayout *IntInputWidgetLayout;
	QIntValidator *iv;
	KCompletionBox *cb;
	QPushButton *pushButton;
	QLineEdit *lineEdit;
	QPixmap image0;
	
	public slots:
	virtual void popup();
	virtual void languageChange();
	virtual void setwidgets( const char* );
	virtual void insert( const QString& );
	virtual void registerValue();
	
	virtual void setValue( int );
	virtual int value();
	virtual void setMinValue( int );
	virtual int minValue();
	virtual void setMaxValue( int );
	virtual int maxValue();
	virtual void addValue( int );
	virtual void subValue( int );
	};

#endif
